# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['HostShareKeyArgs', 'HostShareKey']

@pulumi.input_type
class HostShareKeyArgs:
    def __init__(__self__, *,
                 host_share_key_name: pulumi.Input[str],
                 instance_id: pulumi.Input[str],
                 private_key: pulumi.Input[str],
                 pass_phrase: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a HostShareKey resource.
        :param pulumi.Input[str] host_share_key_name: The name of the host shared key to be added. The name can be a maximum of 128 characters in length.
        :param pulumi.Input[str] instance_id: The ID of the Bastion instance.
        :param pulumi.Input[str] private_key: The private key. The value is a Base64-encoded string.
        :param pulumi.Input[str] pass_phrase: The password of the private key. The value is a Base64-encoded string.
        """
        pulumi.set(__self__, "host_share_key_name", host_share_key_name)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "private_key", private_key)
        if pass_phrase is not None:
            pulumi.set(__self__, "pass_phrase", pass_phrase)

    @property
    @pulumi.getter(name="hostShareKeyName")
    def host_share_key_name(self) -> pulumi.Input[str]:
        """
        The name of the host shared key to be added. The name can be a maximum of 128 characters in length.
        """
        return pulumi.get(self, "host_share_key_name")

    @host_share_key_name.setter
    def host_share_key_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "host_share_key_name", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[str]:
        """
        The ID of the Bastion instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> pulumi.Input[str]:
        """
        The private key. The value is a Base64-encoded string.
        """
        return pulumi.get(self, "private_key")

    @private_key.setter
    def private_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "private_key", value)

    @property
    @pulumi.getter(name="passPhrase")
    def pass_phrase(self) -> Optional[pulumi.Input[str]]:
        """
        The password of the private key. The value is a Base64-encoded string.
        """
        return pulumi.get(self, "pass_phrase")

    @pass_phrase.setter
    def pass_phrase(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pass_phrase", value)


@pulumi.input_type
class _HostShareKeyState:
    def __init__(__self__, *,
                 host_share_key_id: Optional[pulumi.Input[str]] = None,
                 host_share_key_name: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 pass_phrase: Optional[pulumi.Input[str]] = None,
                 private_key: Optional[pulumi.Input[str]] = None,
                 private_key_finger_print: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering HostShareKey resources.
        :param pulumi.Input[str] host_share_key_id: The first ID of the resource.
        :param pulumi.Input[str] host_share_key_name: The name of the host shared key to be added. The name can be a maximum of 128 characters in length.
        :param pulumi.Input[str] instance_id: The ID of the Bastion instance.
        :param pulumi.Input[str] pass_phrase: The password of the private key. The value is a Base64-encoded string.
        :param pulumi.Input[str] private_key: The private key. The value is a Base64-encoded string.
        :param pulumi.Input[str] private_key_finger_print: The fingerprint of the private key.
        """
        if host_share_key_id is not None:
            pulumi.set(__self__, "host_share_key_id", host_share_key_id)
        if host_share_key_name is not None:
            pulumi.set(__self__, "host_share_key_name", host_share_key_name)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if pass_phrase is not None:
            pulumi.set(__self__, "pass_phrase", pass_phrase)
        if private_key is not None:
            pulumi.set(__self__, "private_key", private_key)
        if private_key_finger_print is not None:
            pulumi.set(__self__, "private_key_finger_print", private_key_finger_print)

    @property
    @pulumi.getter(name="hostShareKeyId")
    def host_share_key_id(self) -> Optional[pulumi.Input[str]]:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "host_share_key_id")

    @host_share_key_id.setter
    def host_share_key_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "host_share_key_id", value)

    @property
    @pulumi.getter(name="hostShareKeyName")
    def host_share_key_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the host shared key to be added. The name can be a maximum of 128 characters in length.
        """
        return pulumi.get(self, "host_share_key_name")

    @host_share_key_name.setter
    def host_share_key_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "host_share_key_name", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Bastion instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="passPhrase")
    def pass_phrase(self) -> Optional[pulumi.Input[str]]:
        """
        The password of the private key. The value is a Base64-encoded string.
        """
        return pulumi.get(self, "pass_phrase")

    @pass_phrase.setter
    def pass_phrase(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pass_phrase", value)

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> Optional[pulumi.Input[str]]:
        """
        The private key. The value is a Base64-encoded string.
        """
        return pulumi.get(self, "private_key")

    @private_key.setter
    def private_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_key", value)

    @property
    @pulumi.getter(name="privateKeyFingerPrint")
    def private_key_finger_print(self) -> Optional[pulumi.Input[str]]:
        """
        The fingerprint of the private key.
        """
        return pulumi.get(self, "private_key_finger_print")

    @private_key_finger_print.setter
    def private_key_finger_print(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_key_finger_print", value)


class HostShareKey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 host_share_key_name: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 pass_phrase: Optional[pulumi.Input[str]] = None,
                 private_key: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Bastion Host Share Key resource.

        For information about Bastion Host Host Share Key and how to use it, see [What is Host Share Key](https://www.alibabacloud.com/help/en/bastion-host/latest/createhostsharekey).

        > **NOTE:** Available in v1.165.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default_instances = alicloud.bastionhost.get_instances()
        default_host_share_key = alicloud.bastionhost.HostShareKey("defaultHostShareKey",
            host_share_key_name="example_name",
            instance_id=default_instances.instances[0].id,
            pass_phrase="example_value",
            private_key="example_value")
        ```

        ## Import

        Bastion Host Share Key can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:bastionhost/hostShareKey:HostShareKey example <instance_id>:<host_share_key_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] host_share_key_name: The name of the host shared key to be added. The name can be a maximum of 128 characters in length.
        :param pulumi.Input[str] instance_id: The ID of the Bastion instance.
        :param pulumi.Input[str] pass_phrase: The password of the private key. The value is a Base64-encoded string.
        :param pulumi.Input[str] private_key: The private key. The value is a Base64-encoded string.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: HostShareKeyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Bastion Host Share Key resource.

        For information about Bastion Host Host Share Key and how to use it, see [What is Host Share Key](https://www.alibabacloud.com/help/en/bastion-host/latest/createhostsharekey).

        > **NOTE:** Available in v1.165.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default_instances = alicloud.bastionhost.get_instances()
        default_host_share_key = alicloud.bastionhost.HostShareKey("defaultHostShareKey",
            host_share_key_name="example_name",
            instance_id=default_instances.instances[0].id,
            pass_phrase="example_value",
            private_key="example_value")
        ```

        ## Import

        Bastion Host Share Key can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:bastionhost/hostShareKey:HostShareKey example <instance_id>:<host_share_key_id>
        ```

        :param str resource_name: The name of the resource.
        :param HostShareKeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HostShareKeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 host_share_key_name: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 pass_phrase: Optional[pulumi.Input[str]] = None,
                 private_key: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HostShareKeyArgs.__new__(HostShareKeyArgs)

            if host_share_key_name is None and not opts.urn:
                raise TypeError("Missing required property 'host_share_key_name'")
            __props__.__dict__["host_share_key_name"] = host_share_key_name
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["pass_phrase"] = None if pass_phrase is None else pulumi.Output.secret(pass_phrase)
            if private_key is None and not opts.urn:
                raise TypeError("Missing required property 'private_key'")
            __props__.__dict__["private_key"] = None if private_key is None else pulumi.Output.secret(private_key)
            __props__.__dict__["host_share_key_id"] = None
            __props__.__dict__["private_key_finger_print"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["passPhrase", "privateKey"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(HostShareKey, __self__).__init__(
            'alicloud:bastionhost/hostShareKey:HostShareKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            host_share_key_id: Optional[pulumi.Input[str]] = None,
            host_share_key_name: Optional[pulumi.Input[str]] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            pass_phrase: Optional[pulumi.Input[str]] = None,
            private_key: Optional[pulumi.Input[str]] = None,
            private_key_finger_print: Optional[pulumi.Input[str]] = None) -> 'HostShareKey':
        """
        Get an existing HostShareKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] host_share_key_id: The first ID of the resource.
        :param pulumi.Input[str] host_share_key_name: The name of the host shared key to be added. The name can be a maximum of 128 characters in length.
        :param pulumi.Input[str] instance_id: The ID of the Bastion instance.
        :param pulumi.Input[str] pass_phrase: The password of the private key. The value is a Base64-encoded string.
        :param pulumi.Input[str] private_key: The private key. The value is a Base64-encoded string.
        :param pulumi.Input[str] private_key_finger_print: The fingerprint of the private key.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HostShareKeyState.__new__(_HostShareKeyState)

        __props__.__dict__["host_share_key_id"] = host_share_key_id
        __props__.__dict__["host_share_key_name"] = host_share_key_name
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["pass_phrase"] = pass_phrase
        __props__.__dict__["private_key"] = private_key
        __props__.__dict__["private_key_finger_print"] = private_key_finger_print
        return HostShareKey(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="hostShareKeyId")
    def host_share_key_id(self) -> pulumi.Output[str]:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "host_share_key_id")

    @property
    @pulumi.getter(name="hostShareKeyName")
    def host_share_key_name(self) -> pulumi.Output[str]:
        """
        The name of the host shared key to be added. The name can be a maximum of 128 characters in length.
        """
        return pulumi.get(self, "host_share_key_name")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        The ID of the Bastion instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="passPhrase")
    def pass_phrase(self) -> pulumi.Output[Optional[str]]:
        """
        The password of the private key. The value is a Base64-encoded string.
        """
        return pulumi.get(self, "pass_phrase")

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> pulumi.Output[str]:
        """
        The private key. The value is a Base64-encoded string.
        """
        return pulumi.get(self, "private_key")

    @property
    @pulumi.getter(name="privateKeyFingerPrint")
    def private_key_finger_print(self) -> pulumi.Output[str]:
        """
        The fingerprint of the private key.
        """
        return pulumi.get(self, "private_key_finger_print")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetServerGroupsResult',
    'AwaitableGetServerGroupsResult',
    'get_server_groups',
    'get_server_groups_output',
]

@pulumi.output_type
class GetServerGroupsResult:
    """
    A collection of values returned by getServerGroups.
    """
    def __init__(__self__, groups=None, id=None, ids=None, name_regex=None, names=None, output_file=None, resource_group_id=None, server_group_names=None, server_group_type=None, status=None, tags=None):
        if groups and not isinstance(groups, list):
            raise TypeError("Expected argument 'groups' to be a list")
        pulumi.set(__self__, "groups", groups)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if resource_group_id and not isinstance(resource_group_id, str):
            raise TypeError("Expected argument 'resource_group_id' to be a str")
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        if server_group_names and not isinstance(server_group_names, list):
            raise TypeError("Expected argument 'server_group_names' to be a list")
        pulumi.set(__self__, "server_group_names", server_group_names)
        if server_group_type and not isinstance(server_group_type, str):
            raise TypeError("Expected argument 'server_group_type' to be a str")
        pulumi.set(__self__, "server_group_type", server_group_type)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def groups(self) -> Sequence['outputs.GetServerGroupsGroupResult']:
        return pulumi.get(self, "groups")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[str]:
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="serverGroupNames")
    def server_group_names(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "server_group_names")

    @property
    @pulumi.getter(name="serverGroupType")
    def server_group_type(self) -> Optional[str]:
        return pulumi.get(self, "server_group_type")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, Any]]:
        return pulumi.get(self, "tags")


class AwaitableGetServerGroupsResult(GetServerGroupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServerGroupsResult(
            groups=self.groups,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            resource_group_id=self.resource_group_id,
            server_group_names=self.server_group_names,
            server_group_type=self.server_group_type,
            status=self.status,
            tags=self.tags)


def get_server_groups(ids: Optional[Sequence[str]] = None,
                      name_regex: Optional[str] = None,
                      output_file: Optional[str] = None,
                      resource_group_id: Optional[str] = None,
                      server_group_names: Optional[Sequence[str]] = None,
                      server_group_type: Optional[str] = None,
                      status: Optional[str] = None,
                      tags: Optional[Mapping[str, Any]] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServerGroupsResult:
    """
    This data source provides the Nlb Server Groups of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.186.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.nlb.get_server_groups()
    pulumi.export("nlbServerGroupId1", ids.groups[0].id)
    name_regex = alicloud.nlb.get_server_groups(name_regex="^my-ServerGroup")
    pulumi.export("nlbServerGroupId2", name_regex.groups[0].id)
    ```


    :param Sequence[str] ids: A list of Server Group IDs.
    :param str name_regex: A regex string to filter results by Server Group name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str resource_group_id: The ID of the resource group to which the security group belongs.
    :param Sequence[str] server_group_names: The names of the server groups to be queried.
    :param str server_group_type: The type of the server group.
    :param str status: The status of the server group.
    :param Mapping[str, Any] tags: A mapping of tags to assign to the resource.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['resourceGroupId'] = resource_group_id
    __args__['serverGroupNames'] = server_group_names
    __args__['serverGroupType'] = server_group_type
    __args__['status'] = status
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:nlb/getServerGroups:getServerGroups', __args__, opts=opts, typ=GetServerGroupsResult).value

    return AwaitableGetServerGroupsResult(
        groups=__ret__.groups,
        id=__ret__.id,
        ids=__ret__.ids,
        name_regex=__ret__.name_regex,
        names=__ret__.names,
        output_file=__ret__.output_file,
        resource_group_id=__ret__.resource_group_id,
        server_group_names=__ret__.server_group_names,
        server_group_type=__ret__.server_group_type,
        status=__ret__.status,
        tags=__ret__.tags)


@_utilities.lift_output_func(get_server_groups)
def get_server_groups_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                             name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                             output_file: Optional[pulumi.Input[Optional[str]]] = None,
                             resource_group_id: Optional[pulumi.Input[Optional[str]]] = None,
                             server_group_names: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                             server_group_type: Optional[pulumi.Input[Optional[str]]] = None,
                             status: Optional[pulumi.Input[Optional[str]]] = None,
                             tags: Optional[pulumi.Input[Optional[Mapping[str, Any]]]] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetServerGroupsResult]:
    """
    This data source provides the Nlb Server Groups of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.186.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.nlb.get_server_groups()
    pulumi.export("nlbServerGroupId1", ids.groups[0].id)
    name_regex = alicloud.nlb.get_server_groups(name_regex="^my-ServerGroup")
    pulumi.export("nlbServerGroupId2", name_regex.groups[0].id)
    ```


    :param Sequence[str] ids: A list of Server Group IDs.
    :param str name_regex: A regex string to filter results by Server Group name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str resource_group_id: The ID of the resource group to which the security group belongs.
    :param Sequence[str] server_group_names: The names of the server groups to be queried.
    :param str server_group_type: The type of the server group.
    :param str status: The status of the server group.
    :param Mapping[str, Any] tags: A mapping of tags to assign to the resource.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'ProviderAssumeRoleArgs',
    'ProviderEndpointArgs',
]

@pulumi.input_type
class ProviderAssumeRoleArgs:
    def __init__(__self__, *,
                 role_arn: pulumi.Input[str],
                 policy: Optional[pulumi.Input[str]] = None,
                 session_expiration: Optional[pulumi.Input[int]] = None,
                 session_name: Optional[pulumi.Input[str]] = None):
        pulumi.set(__self__, "role_arn", role_arn)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if session_expiration is not None:
            pulumi.set(__self__, "session_expiration", session_expiration)
        if session_name is not None:
            pulumi.set(__self__, "session_name", session_name)

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> pulumi.Input[str]:
        return pulumi.get(self, "role_arn")

    @role_arn.setter
    def role_arn(self, value: pulumi.Input[str]):
        pulumi.set(self, "role_arn", value)

    @property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy", value)

    @property
    @pulumi.getter(name="sessionExpiration")
    def session_expiration(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "session_expiration")

    @session_expiration.setter
    def session_expiration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "session_expiration", value)

    @property
    @pulumi.getter(name="sessionName")
    def session_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "session_name")

    @session_name.setter
    def session_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "session_name", value)


@pulumi.input_type
class ProviderEndpointArgs:
    def __init__(__self__, *,
                 acr: Optional[pulumi.Input[str]] = None,
                 actiontrail: Optional[pulumi.Input[str]] = None,
                 adb: Optional[pulumi.Input[str]] = None,
                 alb: Optional[pulumi.Input[str]] = None,
                 alidfs: Optional[pulumi.Input[str]] = None,
                 alidns: Optional[pulumi.Input[str]] = None,
                 alikafka: Optional[pulumi.Input[str]] = None,
                 apigateway: Optional[pulumi.Input[str]] = None,
                 arms: Optional[pulumi.Input[str]] = None,
                 bastionhost: Optional[pulumi.Input[str]] = None,
                 beebot: Optional[pulumi.Input[str]] = None,
                 bpstudio: Optional[pulumi.Input[str]] = None,
                 brain_industrial: Optional[pulumi.Input[str]] = None,
                 bssopenapi: Optional[pulumi.Input[str]] = None,
                 cas: Optional[pulumi.Input[str]] = None,
                 cassandra: Optional[pulumi.Input[str]] = None,
                 cbn: Optional[pulumi.Input[str]] = None,
                 cbs: Optional[pulumi.Input[str]] = None,
                 cddc: Optional[pulumi.Input[str]] = None,
                 cdn: Optional[pulumi.Input[str]] = None,
                 cds: Optional[pulumi.Input[str]] = None,
                 clickhouse: Optional[pulumi.Input[str]] = None,
                 cloudauth: Optional[pulumi.Input[str]] = None,
                 cloudfirewall: Optional[pulumi.Input[str]] = None,
                 cloudfw: Optional[pulumi.Input[str]] = None,
                 cloudphone: Optional[pulumi.Input[str]] = None,
                 cloudsso: Optional[pulumi.Input[str]] = None,
                 cms: Optional[pulumi.Input[str]] = None,
                 computenest: Optional[pulumi.Input[str]] = None,
                 config: Optional[pulumi.Input[str]] = None,
                 cr: Optional[pulumi.Input[str]] = None,
                 cs: Optional[pulumi.Input[str]] = None,
                 das: Optional[pulumi.Input[str]] = None,
                 datahub: Optional[pulumi.Input[str]] = None,
                 dataworkspublic: Optional[pulumi.Input[str]] = None,
                 dbfs: Optional[pulumi.Input[str]] = None,
                 dcdn: Optional[pulumi.Input[str]] = None,
                 ddosbasic: Optional[pulumi.Input[str]] = None,
                 ddosbgp: Optional[pulumi.Input[str]] = None,
                 ddoscoo: Optional[pulumi.Input[str]] = None,
                 dds: Optional[pulumi.Input[str]] = None,
                 devopsrdc: Optional[pulumi.Input[str]] = None,
                 dg: Optional[pulumi.Input[str]] = None,
                 dm: Optional[pulumi.Input[str]] = None,
                 dms_enterprise: Optional[pulumi.Input[str]] = None,
                 dmsenterprise: Optional[pulumi.Input[str]] = None,
                 dns: Optional[pulumi.Input[str]] = None,
                 drds: Optional[pulumi.Input[str]] = None,
                 dts: Optional[pulumi.Input[str]] = None,
                 dysms: Optional[pulumi.Input[str]] = None,
                 eais: Optional[pulumi.Input[str]] = None,
                 ebs: Optional[pulumi.Input[str]] = None,
                 eci: Optional[pulumi.Input[str]] = None,
                 ecs: Optional[pulumi.Input[str]] = None,
                 edas: Optional[pulumi.Input[str]] = None,
                 edasschedulerx: Optional[pulumi.Input[str]] = None,
                 edsuser: Optional[pulumi.Input[str]] = None,
                 eflo: Optional[pulumi.Input[str]] = None,
                 ehpc: Optional[pulumi.Input[str]] = None,
                 ehs: Optional[pulumi.Input[str]] = None,
                 eipanycast: Optional[pulumi.Input[str]] = None,
                 elasticsearch: Optional[pulumi.Input[str]] = None,
                 emr: Optional[pulumi.Input[str]] = None,
                 ens: Optional[pulumi.Input[str]] = None,
                 ess: Optional[pulumi.Input[str]] = None,
                 eventbridge: Optional[pulumi.Input[str]] = None,
                 fc: Optional[pulumi.Input[str]] = None,
                 fnf: Optional[pulumi.Input[str]] = None,
                 ga: Optional[pulumi.Input[str]] = None,
                 gaplus: Optional[pulumi.Input[str]] = None,
                 gds: Optional[pulumi.Input[str]] = None,
                 gpdb: Optional[pulumi.Input[str]] = None,
                 gwsecd: Optional[pulumi.Input[str]] = None,
                 hbr: Optional[pulumi.Input[str]] = None,
                 hcs_sgw: Optional[pulumi.Input[str]] = None,
                 hitsdb: Optional[pulumi.Input[str]] = None,
                 imm: Optional[pulumi.Input[str]] = None,
                 imp: Optional[pulumi.Input[str]] = None,
                 ims: Optional[pulumi.Input[str]] = None,
                 iot: Optional[pulumi.Input[str]] = None,
                 kms: Optional[pulumi.Input[str]] = None,
                 kvstore: Optional[pulumi.Input[str]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 log: Optional[pulumi.Input[str]] = None,
                 market: Optional[pulumi.Input[str]] = None,
                 maxcompute: Optional[pulumi.Input[str]] = None,
                 mhub: Optional[pulumi.Input[str]] = None,
                 mns: Optional[pulumi.Input[str]] = None,
                 mscopensubscription: Optional[pulumi.Input[str]] = None,
                 mse: Optional[pulumi.Input[str]] = None,
                 nas: Optional[pulumi.Input[str]] = None,
                 nlb: Optional[pulumi.Input[str]] = None,
                 oceanbase: Optional[pulumi.Input[str]] = None,
                 ons: Optional[pulumi.Input[str]] = None,
                 onsproxy: Optional[pulumi.Input[str]] = None,
                 oos: Optional[pulumi.Input[str]] = None,
                 opensearch: Optional[pulumi.Input[str]] = None,
                 oss: Optional[pulumi.Input[str]] = None,
                 ots: Optional[pulumi.Input[str]] = None,
                 polardb: Optional[pulumi.Input[str]] = None,
                 privatelink: Optional[pulumi.Input[str]] = None,
                 pvtz: Optional[pulumi.Input[str]] = None,
                 quickbi: Optional[pulumi.Input[str]] = None,
                 quotas: Optional[pulumi.Input[str]] = None,
                 r_kvstore: Optional[pulumi.Input[str]] = None,
                 ram: Optional[pulumi.Input[str]] = None,
                 rds: Optional[pulumi.Input[str]] = None,
                 redisa: Optional[pulumi.Input[str]] = None,
                 resourcemanager: Optional[pulumi.Input[str]] = None,
                 resourcesharing: Optional[pulumi.Input[str]] = None,
                 ros: Optional[pulumi.Input[str]] = None,
                 sas: Optional[pulumi.Input[str]] = None,
                 scdn: Optional[pulumi.Input[str]] = None,
                 sddp: Optional[pulumi.Input[str]] = None,
                 serverless: Optional[pulumi.Input[str]] = None,
                 servicemesh: Optional[pulumi.Input[str]] = None,
                 sgw: Optional[pulumi.Input[str]] = None,
                 slb: Optional[pulumi.Input[str]] = None,
                 smartag: Optional[pulumi.Input[str]] = None,
                 srvcatalog: Optional[pulumi.Input[str]] = None,
                 sts: Optional[pulumi.Input[str]] = None,
                 swas: Optional[pulumi.Input[str]] = None,
                 tag: Optional[pulumi.Input[str]] = None,
                 vod: Optional[pulumi.Input[str]] = None,
                 vpc: Optional[pulumi.Input[str]] = None,
                 vpcpeer: Optional[pulumi.Input[str]] = None,
                 vs: Optional[pulumi.Input[str]] = None,
                 waf: Optional[pulumi.Input[str]] = None,
                 waf_openapi: Optional[pulumi.Input[str]] = None):
        if acr is not None:
            pulumi.set(__self__, "acr", acr)
        if actiontrail is not None:
            pulumi.set(__self__, "actiontrail", actiontrail)
        if adb is not None:
            pulumi.set(__self__, "adb", adb)
        if alb is not None:
            pulumi.set(__self__, "alb", alb)
        if alidfs is not None:
            pulumi.set(__self__, "alidfs", alidfs)
        if alidns is not None:
            pulumi.set(__self__, "alidns", alidns)
        if alikafka is not None:
            pulumi.set(__self__, "alikafka", alikafka)
        if apigateway is not None:
            pulumi.set(__self__, "apigateway", apigateway)
        if arms is not None:
            pulumi.set(__self__, "arms", arms)
        if bastionhost is not None:
            pulumi.set(__self__, "bastionhost", bastionhost)
        if beebot is not None:
            pulumi.set(__self__, "beebot", beebot)
        if bpstudio is not None:
            pulumi.set(__self__, "bpstudio", bpstudio)
        if brain_industrial is not None:
            pulumi.set(__self__, "brain_industrial", brain_industrial)
        if bssopenapi is not None:
            pulumi.set(__self__, "bssopenapi", bssopenapi)
        if cas is not None:
            pulumi.set(__self__, "cas", cas)
        if cassandra is not None:
            pulumi.set(__self__, "cassandra", cassandra)
        if cbn is not None:
            pulumi.set(__self__, "cbn", cbn)
        if cbs is not None:
            pulumi.set(__self__, "cbs", cbs)
        if cddc is not None:
            pulumi.set(__self__, "cddc", cddc)
        if cdn is not None:
            pulumi.set(__self__, "cdn", cdn)
        if cds is not None:
            pulumi.set(__self__, "cds", cds)
        if clickhouse is not None:
            pulumi.set(__self__, "clickhouse", clickhouse)
        if cloudauth is not None:
            pulumi.set(__self__, "cloudauth", cloudauth)
        if cloudfirewall is not None:
            pulumi.set(__self__, "cloudfirewall", cloudfirewall)
        if cloudfw is not None:
            pulumi.set(__self__, "cloudfw", cloudfw)
        if cloudphone is not None:
            pulumi.set(__self__, "cloudphone", cloudphone)
        if cloudsso is not None:
            pulumi.set(__self__, "cloudsso", cloudsso)
        if cms is not None:
            pulumi.set(__self__, "cms", cms)
        if computenest is not None:
            pulumi.set(__self__, "computenest", computenest)
        if config is not None:
            pulumi.set(__self__, "config", config)
        if cr is not None:
            pulumi.set(__self__, "cr", cr)
        if cs is not None:
            pulumi.set(__self__, "cs", cs)
        if das is not None:
            pulumi.set(__self__, "das", das)
        if datahub is not None:
            pulumi.set(__self__, "datahub", datahub)
        if dataworkspublic is not None:
            pulumi.set(__self__, "dataworkspublic", dataworkspublic)
        if dbfs is not None:
            pulumi.set(__self__, "dbfs", dbfs)
        if dcdn is not None:
            pulumi.set(__self__, "dcdn", dcdn)
        if ddosbasic is not None:
            pulumi.set(__self__, "ddosbasic", ddosbasic)
        if ddosbgp is not None:
            pulumi.set(__self__, "ddosbgp", ddosbgp)
        if ddoscoo is not None:
            pulumi.set(__self__, "ddoscoo", ddoscoo)
        if dds is not None:
            pulumi.set(__self__, "dds", dds)
        if devopsrdc is not None:
            pulumi.set(__self__, "devopsrdc", devopsrdc)
        if dg is not None:
            pulumi.set(__self__, "dg", dg)
        if dm is not None:
            pulumi.set(__self__, "dm", dm)
        if dms_enterprise is not None:
            pulumi.set(__self__, "dms_enterprise", dms_enterprise)
        if dmsenterprise is not None:
            pulumi.set(__self__, "dmsenterprise", dmsenterprise)
        if dns is not None:
            pulumi.set(__self__, "dns", dns)
        if drds is not None:
            pulumi.set(__self__, "drds", drds)
        if dts is not None:
            pulumi.set(__self__, "dts", dts)
        if dysms is not None:
            pulumi.set(__self__, "dysms", dysms)
        if eais is not None:
            pulumi.set(__self__, "eais", eais)
        if ebs is not None:
            pulumi.set(__self__, "ebs", ebs)
        if eci is not None:
            pulumi.set(__self__, "eci", eci)
        if ecs is not None:
            pulumi.set(__self__, "ecs", ecs)
        if edas is not None:
            pulumi.set(__self__, "edas", edas)
        if edasschedulerx is not None:
            pulumi.set(__self__, "edasschedulerx", edasschedulerx)
        if edsuser is not None:
            pulumi.set(__self__, "edsuser", edsuser)
        if eflo is not None:
            pulumi.set(__self__, "eflo", eflo)
        if ehpc is not None:
            pulumi.set(__self__, "ehpc", ehpc)
        if ehs is not None:
            pulumi.set(__self__, "ehs", ehs)
        if eipanycast is not None:
            pulumi.set(__self__, "eipanycast", eipanycast)
        if elasticsearch is not None:
            pulumi.set(__self__, "elasticsearch", elasticsearch)
        if emr is not None:
            pulumi.set(__self__, "emr", emr)
        if ens is not None:
            pulumi.set(__self__, "ens", ens)
        if ess is not None:
            pulumi.set(__self__, "ess", ess)
        if eventbridge is not None:
            pulumi.set(__self__, "eventbridge", eventbridge)
        if fc is not None:
            pulumi.set(__self__, "fc", fc)
        if fnf is not None:
            pulumi.set(__self__, "fnf", fnf)
        if ga is not None:
            pulumi.set(__self__, "ga", ga)
        if gaplus is not None:
            pulumi.set(__self__, "gaplus", gaplus)
        if gds is not None:
            pulumi.set(__self__, "gds", gds)
        if gpdb is not None:
            pulumi.set(__self__, "gpdb", gpdb)
        if gwsecd is not None:
            pulumi.set(__self__, "gwsecd", gwsecd)
        if hbr is not None:
            pulumi.set(__self__, "hbr", hbr)
        if hcs_sgw is not None:
            pulumi.set(__self__, "hcs_sgw", hcs_sgw)
        if hitsdb is not None:
            pulumi.set(__self__, "hitsdb", hitsdb)
        if imm is not None:
            pulumi.set(__self__, "imm", imm)
        if imp is not None:
            pulumi.set(__self__, "imp", imp)
        if ims is not None:
            pulumi.set(__self__, "ims", ims)
        if iot is not None:
            pulumi.set(__self__, "iot", iot)
        if kms is not None:
            pulumi.set(__self__, "kms", kms)
        if kvstore is not None:
            pulumi.set(__self__, "kvstore", kvstore)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if log is not None:
            pulumi.set(__self__, "log", log)
        if market is not None:
            pulumi.set(__self__, "market", market)
        if maxcompute is not None:
            pulumi.set(__self__, "maxcompute", maxcompute)
        if mhub is not None:
            pulumi.set(__self__, "mhub", mhub)
        if mns is not None:
            pulumi.set(__self__, "mns", mns)
        if mscopensubscription is not None:
            pulumi.set(__self__, "mscopensubscription", mscopensubscription)
        if mse is not None:
            pulumi.set(__self__, "mse", mse)
        if nas is not None:
            pulumi.set(__self__, "nas", nas)
        if nlb is not None:
            pulumi.set(__self__, "nlb", nlb)
        if oceanbase is not None:
            pulumi.set(__self__, "oceanbase", oceanbase)
        if ons is not None:
            pulumi.set(__self__, "ons", ons)
        if onsproxy is not None:
            pulumi.set(__self__, "onsproxy", onsproxy)
        if oos is not None:
            pulumi.set(__self__, "oos", oos)
        if opensearch is not None:
            pulumi.set(__self__, "opensearch", opensearch)
        if oss is not None:
            pulumi.set(__self__, "oss", oss)
        if ots is not None:
            pulumi.set(__self__, "ots", ots)
        if polardb is not None:
            pulumi.set(__self__, "polardb", polardb)
        if privatelink is not None:
            pulumi.set(__self__, "privatelink", privatelink)
        if pvtz is not None:
            pulumi.set(__self__, "pvtz", pvtz)
        if quickbi is not None:
            pulumi.set(__self__, "quickbi", quickbi)
        if quotas is not None:
            pulumi.set(__self__, "quotas", quotas)
        if r_kvstore is not None:
            pulumi.set(__self__, "r_kvstore", r_kvstore)
        if ram is not None:
            pulumi.set(__self__, "ram", ram)
        if rds is not None:
            pulumi.set(__self__, "rds", rds)
        if redisa is not None:
            pulumi.set(__self__, "redisa", redisa)
        if resourcemanager is not None:
            pulumi.set(__self__, "resourcemanager", resourcemanager)
        if resourcesharing is not None:
            pulumi.set(__self__, "resourcesharing", resourcesharing)
        if ros is not None:
            pulumi.set(__self__, "ros", ros)
        if sas is not None:
            pulumi.set(__self__, "sas", sas)
        if scdn is not None:
            pulumi.set(__self__, "scdn", scdn)
        if sddp is not None:
            pulumi.set(__self__, "sddp", sddp)
        if serverless is not None:
            pulumi.set(__self__, "serverless", serverless)
        if servicemesh is not None:
            pulumi.set(__self__, "servicemesh", servicemesh)
        if sgw is not None:
            pulumi.set(__self__, "sgw", sgw)
        if slb is not None:
            pulumi.set(__self__, "slb", slb)
        if smartag is not None:
            pulumi.set(__self__, "smartag", smartag)
        if srvcatalog is not None:
            pulumi.set(__self__, "srvcatalog", srvcatalog)
        if sts is not None:
            pulumi.set(__self__, "sts", sts)
        if swas is not None:
            pulumi.set(__self__, "swas", swas)
        if tag is not None:
            pulumi.set(__self__, "tag", tag)
        if vod is not None:
            pulumi.set(__self__, "vod", vod)
        if vpc is not None:
            pulumi.set(__self__, "vpc", vpc)
        if vpcpeer is not None:
            pulumi.set(__self__, "vpcpeer", vpcpeer)
        if vs is not None:
            pulumi.set(__self__, "vs", vs)
        if waf is not None:
            pulumi.set(__self__, "waf", waf)
        if waf_openapi is not None:
            pulumi.set(__self__, "waf_openapi", waf_openapi)

    @property
    @pulumi.getter
    def acr(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "acr")

    @acr.setter
    def acr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "acr", value)

    @property
    @pulumi.getter
    def actiontrail(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "actiontrail")

    @actiontrail.setter
    def actiontrail(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "actiontrail", value)

    @property
    @pulumi.getter
    def adb(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "adb")

    @adb.setter
    def adb(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "adb", value)

    @property
    @pulumi.getter
    def alb(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "alb")

    @alb.setter
    def alb(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "alb", value)

    @property
    @pulumi.getter
    def alidfs(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "alidfs")

    @alidfs.setter
    def alidfs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "alidfs", value)

    @property
    @pulumi.getter
    def alidns(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "alidns")

    @alidns.setter
    def alidns(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "alidns", value)

    @property
    @pulumi.getter
    def alikafka(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "alikafka")

    @alikafka.setter
    def alikafka(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "alikafka", value)

    @property
    @pulumi.getter
    def apigateway(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "apigateway")

    @apigateway.setter
    def apigateway(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "apigateway", value)

    @property
    @pulumi.getter
    def arms(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "arms")

    @arms.setter
    def arms(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "arms", value)

    @property
    @pulumi.getter
    def bastionhost(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "bastionhost")

    @bastionhost.setter
    def bastionhost(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bastionhost", value)

    @property
    @pulumi.getter
    def beebot(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "beebot")

    @beebot.setter
    def beebot(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "beebot", value)

    @property
    @pulumi.getter
    def bpstudio(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "bpstudio")

    @bpstudio.setter
    def bpstudio(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bpstudio", value)

    @property
    @pulumi.getter(name="brainIndustrial")
    def brain_industrial(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "brain_industrial")

    @brain_industrial.setter
    def brain_industrial(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "brain_industrial", value)

    @property
    @pulumi.getter
    def bssopenapi(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "bssopenapi")

    @bssopenapi.setter
    def bssopenapi(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bssopenapi", value)

    @property
    @pulumi.getter
    def cas(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cas")

    @cas.setter
    def cas(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cas", value)

    @property
    @pulumi.getter
    def cassandra(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cassandra")

    @cassandra.setter
    def cassandra(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cassandra", value)

    @property
    @pulumi.getter
    def cbn(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cbn")

    @cbn.setter
    def cbn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cbn", value)

    @property
    @pulumi.getter
    def cbs(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cbs")

    @cbs.setter
    def cbs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cbs", value)

    @property
    @pulumi.getter
    def cddc(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cddc")

    @cddc.setter
    def cddc(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cddc", value)

    @property
    @pulumi.getter
    def cdn(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cdn")

    @cdn.setter
    def cdn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cdn", value)

    @property
    @pulumi.getter
    def cds(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cds")

    @cds.setter
    def cds(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cds", value)

    @property
    @pulumi.getter
    def clickhouse(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "clickhouse")

    @clickhouse.setter
    def clickhouse(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "clickhouse", value)

    @property
    @pulumi.getter
    def cloudauth(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cloudauth")

    @cloudauth.setter
    def cloudauth(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cloudauth", value)

    @property
    @pulumi.getter
    def cloudfirewall(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cloudfirewall")

    @cloudfirewall.setter
    def cloudfirewall(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cloudfirewall", value)

    @property
    @pulumi.getter
    def cloudfw(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cloudfw")

    @cloudfw.setter
    def cloudfw(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cloudfw", value)

    @property
    @pulumi.getter
    def cloudphone(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cloudphone")

    @cloudphone.setter
    def cloudphone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cloudphone", value)

    @property
    @pulumi.getter
    def cloudsso(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cloudsso")

    @cloudsso.setter
    def cloudsso(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cloudsso", value)

    @property
    @pulumi.getter
    def cms(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cms")

    @cms.setter
    def cms(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cms", value)

    @property
    @pulumi.getter
    def computenest(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "computenest")

    @computenest.setter
    def computenest(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "computenest", value)

    @property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "config", value)

    @property
    @pulumi.getter
    def cr(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cr")

    @cr.setter
    def cr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cr", value)

    @property
    @pulumi.getter
    def cs(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "cs")

    @cs.setter
    def cs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cs", value)

    @property
    @pulumi.getter
    def das(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "das")

    @das.setter
    def das(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "das", value)

    @property
    @pulumi.getter
    def datahub(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "datahub")

    @datahub.setter
    def datahub(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "datahub", value)

    @property
    @pulumi.getter
    def dataworkspublic(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "dataworkspublic")

    @dataworkspublic.setter
    def dataworkspublic(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dataworkspublic", value)

    @property
    @pulumi.getter
    def dbfs(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "dbfs")

    @dbfs.setter
    def dbfs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dbfs", value)

    @property
    @pulumi.getter
    def dcdn(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "dcdn")

    @dcdn.setter
    def dcdn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dcdn", value)

    @property
    @pulumi.getter
    def ddosbasic(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ddosbasic")

    @ddosbasic.setter
    def ddosbasic(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ddosbasic", value)

    @property
    @pulumi.getter
    def ddosbgp(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ddosbgp")

    @ddosbgp.setter
    def ddosbgp(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ddosbgp", value)

    @property
    @pulumi.getter
    def ddoscoo(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ddoscoo")

    @ddoscoo.setter
    def ddoscoo(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ddoscoo", value)

    @property
    @pulumi.getter
    def dds(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "dds")

    @dds.setter
    def dds(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dds", value)

    @property
    @pulumi.getter
    def devopsrdc(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "devopsrdc")

    @devopsrdc.setter
    def devopsrdc(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "devopsrdc", value)

    @property
    @pulumi.getter
    def dg(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "dg")

    @dg.setter
    def dg(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dg", value)

    @property
    @pulumi.getter
    def dm(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "dm")

    @dm.setter
    def dm(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dm", value)

    @property
    @pulumi.getter(name="dmsEnterprise")
    def dms_enterprise(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "dms_enterprise")

    @dms_enterprise.setter
    def dms_enterprise(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dms_enterprise", value)

    @property
    @pulumi.getter
    def dmsenterprise(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "dmsenterprise")

    @dmsenterprise.setter
    def dmsenterprise(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dmsenterprise", value)

    @property
    @pulumi.getter
    def dns(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "dns")

    @dns.setter
    def dns(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dns", value)

    @property
    @pulumi.getter
    def drds(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "drds")

    @drds.setter
    def drds(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "drds", value)

    @property
    @pulumi.getter
    def dts(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "dts")

    @dts.setter
    def dts(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dts", value)

    @property
    @pulumi.getter
    def dysms(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "dysms")

    @dysms.setter
    def dysms(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dysms", value)

    @property
    @pulumi.getter
    def eais(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "eais")

    @eais.setter
    def eais(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "eais", value)

    @property
    @pulumi.getter
    def ebs(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ebs")

    @ebs.setter
    def ebs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ebs", value)

    @property
    @pulumi.getter
    def eci(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "eci")

    @eci.setter
    def eci(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "eci", value)

    @property
    @pulumi.getter
    def ecs(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ecs")

    @ecs.setter
    def ecs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ecs", value)

    @property
    @pulumi.getter
    def edas(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "edas")

    @edas.setter
    def edas(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "edas", value)

    @property
    @pulumi.getter
    def edasschedulerx(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "edasschedulerx")

    @edasschedulerx.setter
    def edasschedulerx(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "edasschedulerx", value)

    @property
    @pulumi.getter
    def edsuser(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "edsuser")

    @edsuser.setter
    def edsuser(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "edsuser", value)

    @property
    @pulumi.getter
    def eflo(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "eflo")

    @eflo.setter
    def eflo(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "eflo", value)

    @property
    @pulumi.getter
    def ehpc(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ehpc")

    @ehpc.setter
    def ehpc(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ehpc", value)

    @property
    @pulumi.getter
    def ehs(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ehs")

    @ehs.setter
    def ehs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ehs", value)

    @property
    @pulumi.getter
    def eipanycast(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "eipanycast")

    @eipanycast.setter
    def eipanycast(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "eipanycast", value)

    @property
    @pulumi.getter
    def elasticsearch(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "elasticsearch")

    @elasticsearch.setter
    def elasticsearch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "elasticsearch", value)

    @property
    @pulumi.getter
    def emr(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "emr")

    @emr.setter
    def emr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "emr", value)

    @property
    @pulumi.getter
    def ens(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ens")

    @ens.setter
    def ens(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ens", value)

    @property
    @pulumi.getter
    def ess(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ess")

    @ess.setter
    def ess(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ess", value)

    @property
    @pulumi.getter
    def eventbridge(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "eventbridge")

    @eventbridge.setter
    def eventbridge(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "eventbridge", value)

    @property
    @pulumi.getter
    def fc(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "fc")

    @fc.setter
    def fc(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fc", value)

    @property
    @pulumi.getter
    def fnf(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "fnf")

    @fnf.setter
    def fnf(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fnf", value)

    @property
    @pulumi.getter
    def ga(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ga")

    @ga.setter
    def ga(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ga", value)

    @property
    @pulumi.getter
    def gaplus(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "gaplus")

    @gaplus.setter
    def gaplus(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gaplus", value)

    @property
    @pulumi.getter
    def gds(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "gds")

    @gds.setter
    def gds(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gds", value)

    @property
    @pulumi.getter
    def gpdb(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "gpdb")

    @gpdb.setter
    def gpdb(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gpdb", value)

    @property
    @pulumi.getter
    def gwsecd(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "gwsecd")

    @gwsecd.setter
    def gwsecd(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gwsecd", value)

    @property
    @pulumi.getter
    def hbr(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "hbr")

    @hbr.setter
    def hbr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hbr", value)

    @property
    @pulumi.getter(name="hcsSgw")
    def hcs_sgw(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "hcs_sgw")

    @hcs_sgw.setter
    def hcs_sgw(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hcs_sgw", value)

    @property
    @pulumi.getter
    def hitsdb(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "hitsdb")

    @hitsdb.setter
    def hitsdb(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hitsdb", value)

    @property
    @pulumi.getter
    def imm(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "imm")

    @imm.setter
    def imm(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "imm", value)

    @property
    @pulumi.getter
    def imp(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "imp")

    @imp.setter
    def imp(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "imp", value)

    @property
    @pulumi.getter
    def ims(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ims")

    @ims.setter
    def ims(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ims", value)

    @property
    @pulumi.getter
    def iot(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "iot")

    @iot.setter
    def iot(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "iot", value)

    @property
    @pulumi.getter
    def kms(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "kms")

    @kms.setter
    def kms(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "kms", value)

    @property
    @pulumi.getter
    def kvstore(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "kvstore")

    @kvstore.setter
    def kvstore(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "kvstore", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def log(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "log")

    @log.setter
    def log(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "log", value)

    @property
    @pulumi.getter
    def market(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "market")

    @market.setter
    def market(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "market", value)

    @property
    @pulumi.getter
    def maxcompute(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "maxcompute")

    @maxcompute.setter
    def maxcompute(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "maxcompute", value)

    @property
    @pulumi.getter
    def mhub(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "mhub")

    @mhub.setter
    def mhub(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mhub", value)

    @property
    @pulumi.getter
    def mns(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "mns")

    @mns.setter
    def mns(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mns", value)

    @property
    @pulumi.getter
    def mscopensubscription(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "mscopensubscription")

    @mscopensubscription.setter
    def mscopensubscription(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mscopensubscription", value)

    @property
    @pulumi.getter
    def mse(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "mse")

    @mse.setter
    def mse(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mse", value)

    @property
    @pulumi.getter
    def nas(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "nas")

    @nas.setter
    def nas(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nas", value)

    @property
    @pulumi.getter
    def nlb(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "nlb")

    @nlb.setter
    def nlb(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nlb", value)

    @property
    @pulumi.getter
    def oceanbase(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "oceanbase")

    @oceanbase.setter
    def oceanbase(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oceanbase", value)

    @property
    @pulumi.getter
    def ons(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ons")

    @ons.setter
    def ons(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ons", value)

    @property
    @pulumi.getter
    def onsproxy(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "onsproxy")

    @onsproxy.setter
    def onsproxy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "onsproxy", value)

    @property
    @pulumi.getter
    def oos(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "oos")

    @oos.setter
    def oos(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oos", value)

    @property
    @pulumi.getter
    def opensearch(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "opensearch")

    @opensearch.setter
    def opensearch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "opensearch", value)

    @property
    @pulumi.getter
    def oss(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "oss")

    @oss.setter
    def oss(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "oss", value)

    @property
    @pulumi.getter
    def ots(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ots")

    @ots.setter
    def ots(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ots", value)

    @property
    @pulumi.getter
    def polardb(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "polardb")

    @polardb.setter
    def polardb(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "polardb", value)

    @property
    @pulumi.getter
    def privatelink(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "privatelink")

    @privatelink.setter
    def privatelink(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "privatelink", value)

    @property
    @pulumi.getter
    def pvtz(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "pvtz")

    @pvtz.setter
    def pvtz(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pvtz", value)

    @property
    @pulumi.getter
    def quickbi(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "quickbi")

    @quickbi.setter
    def quickbi(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "quickbi", value)

    @property
    @pulumi.getter
    def quotas(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "quotas")

    @quotas.setter
    def quotas(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "quotas", value)

    @property
    @pulumi.getter(name="rKvstore")
    def r_kvstore(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "r_kvstore")

    @r_kvstore.setter
    def r_kvstore(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "r_kvstore", value)

    @property
    @pulumi.getter
    def ram(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ram")

    @ram.setter
    def ram(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ram", value)

    @property
    @pulumi.getter
    def rds(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "rds")

    @rds.setter
    def rds(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rds", value)

    @property
    @pulumi.getter
    def redisa(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "redisa")

    @redisa.setter
    def redisa(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "redisa", value)

    @property
    @pulumi.getter
    def resourcemanager(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "resourcemanager")

    @resourcemanager.setter
    def resourcemanager(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resourcemanager", value)

    @property
    @pulumi.getter
    def resourcesharing(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "resourcesharing")

    @resourcesharing.setter
    def resourcesharing(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resourcesharing", value)

    @property
    @pulumi.getter
    def ros(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "ros")

    @ros.setter
    def ros(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ros", value)

    @property
    @pulumi.getter
    def sas(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "sas")

    @sas.setter
    def sas(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sas", value)

    @property
    @pulumi.getter
    def scdn(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "scdn")

    @scdn.setter
    def scdn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scdn", value)

    @property
    @pulumi.getter
    def sddp(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "sddp")

    @sddp.setter
    def sddp(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sddp", value)

    @property
    @pulumi.getter
    def serverless(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "serverless")

    @serverless.setter
    def serverless(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "serverless", value)

    @property
    @pulumi.getter
    def servicemesh(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "servicemesh")

    @servicemesh.setter
    def servicemesh(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "servicemesh", value)

    @property
    @pulumi.getter
    def sgw(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "sgw")

    @sgw.setter
    def sgw(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sgw", value)

    @property
    @pulumi.getter
    def slb(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "slb")

    @slb.setter
    def slb(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "slb", value)

    @property
    @pulumi.getter
    def smartag(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "smartag")

    @smartag.setter
    def smartag(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "smartag", value)

    @property
    @pulumi.getter
    def srvcatalog(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "srvcatalog")

    @srvcatalog.setter
    def srvcatalog(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "srvcatalog", value)

    @property
    @pulumi.getter
    def sts(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "sts")

    @sts.setter
    def sts(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sts", value)

    @property
    @pulumi.getter
    def swas(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "swas")

    @swas.setter
    def swas(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "swas", value)

    @property
    @pulumi.getter
    def tag(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "tag")

    @tag.setter
    def tag(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tag", value)

    @property
    @pulumi.getter
    def vod(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "vod")

    @vod.setter
    def vod(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vod", value)

    @property
    @pulumi.getter
    def vpc(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "vpc")

    @vpc.setter
    def vpc(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc", value)

    @property
    @pulumi.getter
    def vpcpeer(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "vpcpeer")

    @vpcpeer.setter
    def vpcpeer(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpcpeer", value)

    @property
    @pulumi.getter
    def vs(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "vs")

    @vs.setter
    def vs(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vs", value)

    @property
    @pulumi.getter
    def waf(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "waf")

    @waf.setter
    def waf(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "waf", value)

    @property
    @pulumi.getter(name="wafOpenapi")
    def waf_openapi(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "waf_openapi")

    @waf_openapi.setter
    def waf_openapi(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "waf_openapi", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetPrefixListsResult',
    'AwaitableGetPrefixListsResult',
    'get_prefix_lists',
    'get_prefix_lists_output',
]

@pulumi.output_type
class GetPrefixListsResult:
    """
    A collection of values returned by getPrefixLists.
    """
    def __init__(__self__, enable_details=None, id=None, ids=None, lists=None, name_regex=None, names=None, output_file=None, prefix_list_name=None):
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if lists and not isinstance(lists, list):
            raise TypeError("Expected argument 'lists' to be a list")
        pulumi.set(__self__, "lists", lists)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if prefix_list_name and not isinstance(prefix_list_name, str):
            raise TypeError("Expected argument 'prefix_list_name' to be a str")
        pulumi.set(__self__, "prefix_list_name", prefix_list_name)

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def lists(self) -> Sequence['outputs.GetPrefixListsListResult']:
        return pulumi.get(self, "lists")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="prefixListName")
    def prefix_list_name(self) -> Optional[str]:
        return pulumi.get(self, "prefix_list_name")


class AwaitableGetPrefixListsResult(GetPrefixListsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPrefixListsResult(
            enable_details=self.enable_details,
            id=self.id,
            ids=self.ids,
            lists=self.lists,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            prefix_list_name=self.prefix_list_name)


def get_prefix_lists(enable_details: Optional[bool] = None,
                     ids: Optional[Sequence[str]] = None,
                     name_regex: Optional[str] = None,
                     output_file: Optional[str] = None,
                     prefix_list_name: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPrefixListsResult:
    """
    This data source provides the Vpc Prefix Lists of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.182.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.vpc.get_prefix_lists()
    pulumi.export("vpcPrefixListId1", ids.lists[0].id)
    name_regex = alicloud.vpc.get_prefix_lists(name_regex="^my-PrefixList")
    pulumi.export("vpcPrefixListId2", name_regex.lists[0].id)
    ```


    :param bool enable_details: Default to `true`. Set it to `false` can hide the `entrys` to output.
    :param Sequence[str] ids: A list of Prefix List IDs.
    :param str name_regex: A regex string to filter results by Prefix List name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str prefix_list_name: The name of the prefix list.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['prefixListName'] = prefix_list_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:vpc/getPrefixLists:getPrefixLists', __args__, opts=opts, typ=GetPrefixListsResult).value

    return AwaitableGetPrefixListsResult(
        enable_details=__ret__.enable_details,
        id=__ret__.id,
        ids=__ret__.ids,
        lists=__ret__.lists,
        name_regex=__ret__.name_regex,
        names=__ret__.names,
        output_file=__ret__.output_file,
        prefix_list_name=__ret__.prefix_list_name)


@_utilities.lift_output_func(get_prefix_lists)
def get_prefix_lists_output(enable_details: Optional[pulumi.Input[Optional[bool]]] = None,
                            ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                            name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                            output_file: Optional[pulumi.Input[Optional[str]]] = None,
                            prefix_list_name: Optional[pulumi.Input[Optional[str]]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetPrefixListsResult]:
    """
    This data source provides the Vpc Prefix Lists of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.182.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.vpc.get_prefix_lists()
    pulumi.export("vpcPrefixListId1", ids.lists[0].id)
    name_regex = alicloud.vpc.get_prefix_lists(name_regex="^my-PrefixList")
    pulumi.export("vpcPrefixListId2", name_regex.lists[0].id)
    ```


    :param bool enable_details: Default to `true`. Set it to `false` can hide the `entrys` to output.
    :param Sequence[str] ids: A list of Prefix List IDs.
    :param str name_regex: A regex string to filter results by Prefix List name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str prefix_list_name: The name of the prefix list.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['NasBackupPlanArgs', 'NasBackupPlan']

@pulumi.input_type
class NasBackupPlanArgs:
    def __init__(__self__, *,
                 backup_type: pulumi.Input[str],
                 file_system_id: pulumi.Input[str],
                 nas_backup_plan_name: pulumi.Input[str],
                 paths: pulumi.Input[Sequence[pulumi.Input[str]]],
                 retention: pulumi.Input[str],
                 schedule: pulumi.Input[str],
                 vault_id: pulumi.Input[str],
                 create_time: Optional[pulumi.Input[str]] = None,
                 cross_account_role_name: Optional[pulumi.Input[str]] = None,
                 cross_account_type: Optional[pulumi.Input[str]] = None,
                 cross_account_user_id: Optional[pulumi.Input[int]] = None,
                 disabled: Optional[pulumi.Input[bool]] = None,
                 options: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a NasBackupPlan resource.
        :param pulumi.Input[str] backup_type: Backup type. Valid values: `COMPLETE`.
        :param pulumi.Input[str] file_system_id: The File System ID of Nas.
        :param pulumi.Input[str] nas_backup_plan_name: The name of the backup plan. 1~64 characters, the backup plan name of each data source type in a single warehouse required to be unique.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] paths: List of backup path. Up to 65536 characters. e.g.`["/home", "/var"]`. **Note** You should at least specify a backup path, empty array not allowed here.
        :param pulumi.Input[str] retention: Backup retention days, the minimum is 1.
        :param pulumi.Input[str] schedule: Backup strategy. Optional format: `I|{startTime}|{interval}`. It means to execute a backup task every `{interval}` starting from `{startTime}`. The backup task for the elapsed time will not be compensated. If the last backup task has not completed yet, the next backup task will not be triggered.
        :param pulumi.Input[str] vault_id: The ID of Backup vault.
        :param pulumi.Input[str] create_time: This field has been deprecated from provider version 1.153.0+. The creation time of NAS file system. **Note** The time format of the API adopts the ISO 8601, such as `2021-07-09T15:45:30CST` or `2021-07-09T07:45:30Z`.
        :param pulumi.Input[str] cross_account_role_name: The role name created in the original account RAM backup by the cross account managed by the current account.
               
               > **Note** `hbr.NasBackupPlan` depends on the `nas.FileSystem` and creates a mount point on the file system. If this dependency has not declared, the file system may not be deleted correctly.
        :param pulumi.Input[str] cross_account_type: The type of the cross account backup. Valid values: `SELF_ACCOUNT`, `CROSS_ACCOUNT`.
        :param pulumi.Input[int] cross_account_user_id: The original account ID of the cross account backup managed by the current account.
        :param pulumi.Input[bool] disabled: Whether to disable the backup task. Valid values: `true`, `false`.
        :param pulumi.Input[str] options: This parameter specifies whether to use Windows VSS to define a backup path.
        """
        pulumi.set(__self__, "backup_type", backup_type)
        pulumi.set(__self__, "file_system_id", file_system_id)
        pulumi.set(__self__, "nas_backup_plan_name", nas_backup_plan_name)
        pulumi.set(__self__, "paths", paths)
        pulumi.set(__self__, "retention", retention)
        pulumi.set(__self__, "schedule", schedule)
        pulumi.set(__self__, "vault_id", vault_id)
        if create_time is not None:
            warnings.warn("""Field 'create_time' has been deprecated from provider version 1.153.0.""", DeprecationWarning)
            pulumi.log.warn("""create_time is deprecated: Field 'create_time' has been deprecated from provider version 1.153.0.""")
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if cross_account_role_name is not None:
            pulumi.set(__self__, "cross_account_role_name", cross_account_role_name)
        if cross_account_type is not None:
            pulumi.set(__self__, "cross_account_type", cross_account_type)
        if cross_account_user_id is not None:
            pulumi.set(__self__, "cross_account_user_id", cross_account_user_id)
        if disabled is not None:
            pulumi.set(__self__, "disabled", disabled)
        if options is not None:
            pulumi.set(__self__, "options", options)

    @property
    @pulumi.getter(name="backupType")
    def backup_type(self) -> pulumi.Input[str]:
        """
        Backup type. Valid values: `COMPLETE`.
        """
        return pulumi.get(self, "backup_type")

    @backup_type.setter
    def backup_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "backup_type", value)

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> pulumi.Input[str]:
        """
        The File System ID of Nas.
        """
        return pulumi.get(self, "file_system_id")

    @file_system_id.setter
    def file_system_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "file_system_id", value)

    @property
    @pulumi.getter(name="nasBackupPlanName")
    def nas_backup_plan_name(self) -> pulumi.Input[str]:
        """
        The name of the backup plan. 1~64 characters, the backup plan name of each data source type in a single warehouse required to be unique.
        """
        return pulumi.get(self, "nas_backup_plan_name")

    @nas_backup_plan_name.setter
    def nas_backup_plan_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "nas_backup_plan_name", value)

    @property
    @pulumi.getter
    def paths(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        List of backup path. Up to 65536 characters. e.g.`["/home", "/var"]`. **Note** You should at least specify a backup path, empty array not allowed here.
        """
        return pulumi.get(self, "paths")

    @paths.setter
    def paths(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "paths", value)

    @property
    @pulumi.getter
    def retention(self) -> pulumi.Input[str]:
        """
        Backup retention days, the minimum is 1.
        """
        return pulumi.get(self, "retention")

    @retention.setter
    def retention(self, value: pulumi.Input[str]):
        pulumi.set(self, "retention", value)

    @property
    @pulumi.getter
    def schedule(self) -> pulumi.Input[str]:
        """
        Backup strategy. Optional format: `I|{startTime}|{interval}`. It means to execute a backup task every `{interval}` starting from `{startTime}`. The backup task for the elapsed time will not be compensated. If the last backup task has not completed yet, the next backup task will not be triggered.
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: pulumi.Input[str]):
        pulumi.set(self, "schedule", value)

    @property
    @pulumi.getter(name="vaultId")
    def vault_id(self) -> pulumi.Input[str]:
        """
        The ID of Backup vault.
        """
        return pulumi.get(self, "vault_id")

    @vault_id.setter
    def vault_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vault_id", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        This field has been deprecated from provider version 1.153.0+. The creation time of NAS file system. **Note** The time format of the API adopts the ISO 8601, such as `2021-07-09T15:45:30CST` or `2021-07-09T07:45:30Z`.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="crossAccountRoleName")
    def cross_account_role_name(self) -> Optional[pulumi.Input[str]]:
        """
        The role name created in the original account RAM backup by the cross account managed by the current account.

        > **Note** `hbr.NasBackupPlan` depends on the `nas.FileSystem` and creates a mount point on the file system. If this dependency has not declared, the file system may not be deleted correctly.
        """
        return pulumi.get(self, "cross_account_role_name")

    @cross_account_role_name.setter
    def cross_account_role_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cross_account_role_name", value)

    @property
    @pulumi.getter(name="crossAccountType")
    def cross_account_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the cross account backup. Valid values: `SELF_ACCOUNT`, `CROSS_ACCOUNT`.
        """
        return pulumi.get(self, "cross_account_type")

    @cross_account_type.setter
    def cross_account_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cross_account_type", value)

    @property
    @pulumi.getter(name="crossAccountUserId")
    def cross_account_user_id(self) -> Optional[pulumi.Input[int]]:
        """
        The original account ID of the cross account backup managed by the current account.
        """
        return pulumi.get(self, "cross_account_user_id")

    @cross_account_user_id.setter
    def cross_account_user_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cross_account_user_id", value)

    @property
    @pulumi.getter
    def disabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to disable the backup task. Valid values: `true`, `false`.
        """
        return pulumi.get(self, "disabled")

    @disabled.setter
    def disabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disabled", value)

    @property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input[str]]:
        """
        This parameter specifies whether to use Windows VSS to define a backup path.
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "options", value)


@pulumi.input_type
class _NasBackupPlanState:
    def __init__(__self__, *,
                 backup_type: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 cross_account_role_name: Optional[pulumi.Input[str]] = None,
                 cross_account_type: Optional[pulumi.Input[str]] = None,
                 cross_account_user_id: Optional[pulumi.Input[int]] = None,
                 disabled: Optional[pulumi.Input[bool]] = None,
                 file_system_id: Optional[pulumi.Input[str]] = None,
                 nas_backup_plan_name: Optional[pulumi.Input[str]] = None,
                 options: Optional[pulumi.Input[str]] = None,
                 paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 retention: Optional[pulumi.Input[str]] = None,
                 schedule: Optional[pulumi.Input[str]] = None,
                 vault_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering NasBackupPlan resources.
        :param pulumi.Input[str] backup_type: Backup type. Valid values: `COMPLETE`.
        :param pulumi.Input[str] create_time: This field has been deprecated from provider version 1.153.0+. The creation time of NAS file system. **Note** The time format of the API adopts the ISO 8601, such as `2021-07-09T15:45:30CST` or `2021-07-09T07:45:30Z`.
        :param pulumi.Input[str] cross_account_role_name: The role name created in the original account RAM backup by the cross account managed by the current account.
               
               > **Note** `hbr.NasBackupPlan` depends on the `nas.FileSystem` and creates a mount point on the file system. If this dependency has not declared, the file system may not be deleted correctly.
        :param pulumi.Input[str] cross_account_type: The type of the cross account backup. Valid values: `SELF_ACCOUNT`, `CROSS_ACCOUNT`.
        :param pulumi.Input[int] cross_account_user_id: The original account ID of the cross account backup managed by the current account.
        :param pulumi.Input[bool] disabled: Whether to disable the backup task. Valid values: `true`, `false`.
        :param pulumi.Input[str] file_system_id: The File System ID of Nas.
        :param pulumi.Input[str] nas_backup_plan_name: The name of the backup plan. 1~64 characters, the backup plan name of each data source type in a single warehouse required to be unique.
        :param pulumi.Input[str] options: This parameter specifies whether to use Windows VSS to define a backup path.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] paths: List of backup path. Up to 65536 characters. e.g.`["/home", "/var"]`. **Note** You should at least specify a backup path, empty array not allowed here.
        :param pulumi.Input[str] retention: Backup retention days, the minimum is 1.
        :param pulumi.Input[str] schedule: Backup strategy. Optional format: `I|{startTime}|{interval}`. It means to execute a backup task every `{interval}` starting from `{startTime}`. The backup task for the elapsed time will not be compensated. If the last backup task has not completed yet, the next backup task will not be triggered.
        :param pulumi.Input[str] vault_id: The ID of Backup vault.
        """
        if backup_type is not None:
            pulumi.set(__self__, "backup_type", backup_type)
        if create_time is not None:
            warnings.warn("""Field 'create_time' has been deprecated from provider version 1.153.0.""", DeprecationWarning)
            pulumi.log.warn("""create_time is deprecated: Field 'create_time' has been deprecated from provider version 1.153.0.""")
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if cross_account_role_name is not None:
            pulumi.set(__self__, "cross_account_role_name", cross_account_role_name)
        if cross_account_type is not None:
            pulumi.set(__self__, "cross_account_type", cross_account_type)
        if cross_account_user_id is not None:
            pulumi.set(__self__, "cross_account_user_id", cross_account_user_id)
        if disabled is not None:
            pulumi.set(__self__, "disabled", disabled)
        if file_system_id is not None:
            pulumi.set(__self__, "file_system_id", file_system_id)
        if nas_backup_plan_name is not None:
            pulumi.set(__self__, "nas_backup_plan_name", nas_backup_plan_name)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if paths is not None:
            pulumi.set(__self__, "paths", paths)
        if retention is not None:
            pulumi.set(__self__, "retention", retention)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)
        if vault_id is not None:
            pulumi.set(__self__, "vault_id", vault_id)

    @property
    @pulumi.getter(name="backupType")
    def backup_type(self) -> Optional[pulumi.Input[str]]:
        """
        Backup type. Valid values: `COMPLETE`.
        """
        return pulumi.get(self, "backup_type")

    @backup_type.setter
    def backup_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "backup_type", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        This field has been deprecated from provider version 1.153.0+. The creation time of NAS file system. **Note** The time format of the API adopts the ISO 8601, such as `2021-07-09T15:45:30CST` or `2021-07-09T07:45:30Z`.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="crossAccountRoleName")
    def cross_account_role_name(self) -> Optional[pulumi.Input[str]]:
        """
        The role name created in the original account RAM backup by the cross account managed by the current account.

        > **Note** `hbr.NasBackupPlan` depends on the `nas.FileSystem` and creates a mount point on the file system. If this dependency has not declared, the file system may not be deleted correctly.
        """
        return pulumi.get(self, "cross_account_role_name")

    @cross_account_role_name.setter
    def cross_account_role_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cross_account_role_name", value)

    @property
    @pulumi.getter(name="crossAccountType")
    def cross_account_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the cross account backup. Valid values: `SELF_ACCOUNT`, `CROSS_ACCOUNT`.
        """
        return pulumi.get(self, "cross_account_type")

    @cross_account_type.setter
    def cross_account_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cross_account_type", value)

    @property
    @pulumi.getter(name="crossAccountUserId")
    def cross_account_user_id(self) -> Optional[pulumi.Input[int]]:
        """
        The original account ID of the cross account backup managed by the current account.
        """
        return pulumi.get(self, "cross_account_user_id")

    @cross_account_user_id.setter
    def cross_account_user_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cross_account_user_id", value)

    @property
    @pulumi.getter
    def disabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to disable the backup task. Valid values: `true`, `false`.
        """
        return pulumi.get(self, "disabled")

    @disabled.setter
    def disabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disabled", value)

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> Optional[pulumi.Input[str]]:
        """
        The File System ID of Nas.
        """
        return pulumi.get(self, "file_system_id")

    @file_system_id.setter
    def file_system_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "file_system_id", value)

    @property
    @pulumi.getter(name="nasBackupPlanName")
    def nas_backup_plan_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the backup plan. 1~64 characters, the backup plan name of each data source type in a single warehouse required to be unique.
        """
        return pulumi.get(self, "nas_backup_plan_name")

    @nas_backup_plan_name.setter
    def nas_backup_plan_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nas_backup_plan_name", value)

    @property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input[str]]:
        """
        This parameter specifies whether to use Windows VSS to define a backup path.
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "options", value)

    @property
    @pulumi.getter
    def paths(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of backup path. Up to 65536 characters. e.g.`["/home", "/var"]`. **Note** You should at least specify a backup path, empty array not allowed here.
        """
        return pulumi.get(self, "paths")

    @paths.setter
    def paths(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "paths", value)

    @property
    @pulumi.getter
    def retention(self) -> Optional[pulumi.Input[str]]:
        """
        Backup retention days, the minimum is 1.
        """
        return pulumi.get(self, "retention")

    @retention.setter
    def retention(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "retention", value)

    @property
    @pulumi.getter
    def schedule(self) -> Optional[pulumi.Input[str]]:
        """
        Backup strategy. Optional format: `I|{startTime}|{interval}`. It means to execute a backup task every `{interval}` starting from `{startTime}`. The backup task for the elapsed time will not be compensated. If the last backup task has not completed yet, the next backup task will not be triggered.
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schedule", value)

    @property
    @pulumi.getter(name="vaultId")
    def vault_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of Backup vault.
        """
        return pulumi.get(self, "vault_id")

    @vault_id.setter
    def vault_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vault_id", value)


class NasBackupPlan(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backup_type: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 cross_account_role_name: Optional[pulumi.Input[str]] = None,
                 cross_account_type: Optional[pulumi.Input[str]] = None,
                 cross_account_user_id: Optional[pulumi.Input[int]] = None,
                 disabled: Optional[pulumi.Input[bool]] = None,
                 file_system_id: Optional[pulumi.Input[str]] = None,
                 nas_backup_plan_name: Optional[pulumi.Input[str]] = None,
                 options: Optional[pulumi.Input[str]] = None,
                 paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 retention: Optional[pulumi.Input[str]] = None,
                 schedule: Optional[pulumi.Input[str]] = None,
                 vault_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a HBR Nas Backup Plan resource.

        For information about HBR Nas Backup Plan and how to use it, see [What is Nas Backup Plan](https://www.alibabacloud.com/help/doc-detail/132248.htm).

        > **NOTE:** Available in v1.132.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-testAccHBRNas"
        default_vault = alicloud.hbr.Vault("defaultVault", vault_name=name)
        default_file_system = alicloud.nas.FileSystem("defaultFileSystem",
            protocol_type="NFS",
            storage_type="Performance",
            description=name,
            encrypt_type=1)
        default_file_systems = default_file_system.description.apply(lambda description: alicloud.nas.get_file_systems_output(protocol_type="NFS",
            description_regex=description))
        default_nas_backup_plan = alicloud.hbr.NasBackupPlan("defaultNasBackupPlan",
            nas_backup_plan_name=name,
            file_system_id=default_file_system.id,
            schedule="I|1602673264|PT2H",
            backup_type="COMPLETE",
            vault_id=default_vault.id,
            create_time=default_file_systems.systems[0].create_time,
            retention="2",
            paths=["/"],
            opts=pulumi.ResourceOptions(depends_on=["alicloud_nas_file_system.default"]))
        ```

        ## Import

        HBR Nas Backup Plan can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:hbr/nasBackupPlan:NasBackupPlan example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backup_type: Backup type. Valid values: `COMPLETE`.
        :param pulumi.Input[str] create_time: This field has been deprecated from provider version 1.153.0+. The creation time of NAS file system. **Note** The time format of the API adopts the ISO 8601, such as `2021-07-09T15:45:30CST` or `2021-07-09T07:45:30Z`.
        :param pulumi.Input[str] cross_account_role_name: The role name created in the original account RAM backup by the cross account managed by the current account.
               
               > **Note** `hbr.NasBackupPlan` depends on the `nas.FileSystem` and creates a mount point on the file system. If this dependency has not declared, the file system may not be deleted correctly.
        :param pulumi.Input[str] cross_account_type: The type of the cross account backup. Valid values: `SELF_ACCOUNT`, `CROSS_ACCOUNT`.
        :param pulumi.Input[int] cross_account_user_id: The original account ID of the cross account backup managed by the current account.
        :param pulumi.Input[bool] disabled: Whether to disable the backup task. Valid values: `true`, `false`.
        :param pulumi.Input[str] file_system_id: The File System ID of Nas.
        :param pulumi.Input[str] nas_backup_plan_name: The name of the backup plan. 1~64 characters, the backup plan name of each data source type in a single warehouse required to be unique.
        :param pulumi.Input[str] options: This parameter specifies whether to use Windows VSS to define a backup path.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] paths: List of backup path. Up to 65536 characters. e.g.`["/home", "/var"]`. **Note** You should at least specify a backup path, empty array not allowed here.
        :param pulumi.Input[str] retention: Backup retention days, the minimum is 1.
        :param pulumi.Input[str] schedule: Backup strategy. Optional format: `I|{startTime}|{interval}`. It means to execute a backup task every `{interval}` starting from `{startTime}`. The backup task for the elapsed time will not be compensated. If the last backup task has not completed yet, the next backup task will not be triggered.
        :param pulumi.Input[str] vault_id: The ID of Backup vault.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NasBackupPlanArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a HBR Nas Backup Plan resource.

        For information about HBR Nas Backup Plan and how to use it, see [What is Nas Backup Plan](https://www.alibabacloud.com/help/doc-detail/132248.htm).

        > **NOTE:** Available in v1.132.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-testAccHBRNas"
        default_vault = alicloud.hbr.Vault("defaultVault", vault_name=name)
        default_file_system = alicloud.nas.FileSystem("defaultFileSystem",
            protocol_type="NFS",
            storage_type="Performance",
            description=name,
            encrypt_type=1)
        default_file_systems = default_file_system.description.apply(lambda description: alicloud.nas.get_file_systems_output(protocol_type="NFS",
            description_regex=description))
        default_nas_backup_plan = alicloud.hbr.NasBackupPlan("defaultNasBackupPlan",
            nas_backup_plan_name=name,
            file_system_id=default_file_system.id,
            schedule="I|1602673264|PT2H",
            backup_type="COMPLETE",
            vault_id=default_vault.id,
            create_time=default_file_systems.systems[0].create_time,
            retention="2",
            paths=["/"],
            opts=pulumi.ResourceOptions(depends_on=["alicloud_nas_file_system.default"]))
        ```

        ## Import

        HBR Nas Backup Plan can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:hbr/nasBackupPlan:NasBackupPlan example <id>
        ```

        :param str resource_name: The name of the resource.
        :param NasBackupPlanArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NasBackupPlanArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backup_type: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 cross_account_role_name: Optional[pulumi.Input[str]] = None,
                 cross_account_type: Optional[pulumi.Input[str]] = None,
                 cross_account_user_id: Optional[pulumi.Input[int]] = None,
                 disabled: Optional[pulumi.Input[bool]] = None,
                 file_system_id: Optional[pulumi.Input[str]] = None,
                 nas_backup_plan_name: Optional[pulumi.Input[str]] = None,
                 options: Optional[pulumi.Input[str]] = None,
                 paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 retention: Optional[pulumi.Input[str]] = None,
                 schedule: Optional[pulumi.Input[str]] = None,
                 vault_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NasBackupPlanArgs.__new__(NasBackupPlanArgs)

            if backup_type is None and not opts.urn:
                raise TypeError("Missing required property 'backup_type'")
            __props__.__dict__["backup_type"] = backup_type
            if create_time is not None and not opts.urn:
                warnings.warn("""Field 'create_time' has been deprecated from provider version 1.153.0.""", DeprecationWarning)
                pulumi.log.warn("""create_time is deprecated: Field 'create_time' has been deprecated from provider version 1.153.0.""")
            __props__.__dict__["create_time"] = create_time
            __props__.__dict__["cross_account_role_name"] = cross_account_role_name
            __props__.__dict__["cross_account_type"] = cross_account_type
            __props__.__dict__["cross_account_user_id"] = cross_account_user_id
            __props__.__dict__["disabled"] = disabled
            if file_system_id is None and not opts.urn:
                raise TypeError("Missing required property 'file_system_id'")
            __props__.__dict__["file_system_id"] = file_system_id
            if nas_backup_plan_name is None and not opts.urn:
                raise TypeError("Missing required property 'nas_backup_plan_name'")
            __props__.__dict__["nas_backup_plan_name"] = nas_backup_plan_name
            __props__.__dict__["options"] = options
            if paths is None and not opts.urn:
                raise TypeError("Missing required property 'paths'")
            __props__.__dict__["paths"] = paths
            if retention is None and not opts.urn:
                raise TypeError("Missing required property 'retention'")
            __props__.__dict__["retention"] = retention
            if schedule is None and not opts.urn:
                raise TypeError("Missing required property 'schedule'")
            __props__.__dict__["schedule"] = schedule
            if vault_id is None and not opts.urn:
                raise TypeError("Missing required property 'vault_id'")
            __props__.__dict__["vault_id"] = vault_id
        super(NasBackupPlan, __self__).__init__(
            'alicloud:hbr/nasBackupPlan:NasBackupPlan',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backup_type: Optional[pulumi.Input[str]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            cross_account_role_name: Optional[pulumi.Input[str]] = None,
            cross_account_type: Optional[pulumi.Input[str]] = None,
            cross_account_user_id: Optional[pulumi.Input[int]] = None,
            disabled: Optional[pulumi.Input[bool]] = None,
            file_system_id: Optional[pulumi.Input[str]] = None,
            nas_backup_plan_name: Optional[pulumi.Input[str]] = None,
            options: Optional[pulumi.Input[str]] = None,
            paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            retention: Optional[pulumi.Input[str]] = None,
            schedule: Optional[pulumi.Input[str]] = None,
            vault_id: Optional[pulumi.Input[str]] = None) -> 'NasBackupPlan':
        """
        Get an existing NasBackupPlan resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backup_type: Backup type. Valid values: `COMPLETE`.
        :param pulumi.Input[str] create_time: This field has been deprecated from provider version 1.153.0+. The creation time of NAS file system. **Note** The time format of the API adopts the ISO 8601, such as `2021-07-09T15:45:30CST` or `2021-07-09T07:45:30Z`.
        :param pulumi.Input[str] cross_account_role_name: The role name created in the original account RAM backup by the cross account managed by the current account.
               
               > **Note** `hbr.NasBackupPlan` depends on the `nas.FileSystem` and creates a mount point on the file system. If this dependency has not declared, the file system may not be deleted correctly.
        :param pulumi.Input[str] cross_account_type: The type of the cross account backup. Valid values: `SELF_ACCOUNT`, `CROSS_ACCOUNT`.
        :param pulumi.Input[int] cross_account_user_id: The original account ID of the cross account backup managed by the current account.
        :param pulumi.Input[bool] disabled: Whether to disable the backup task. Valid values: `true`, `false`.
        :param pulumi.Input[str] file_system_id: The File System ID of Nas.
        :param pulumi.Input[str] nas_backup_plan_name: The name of the backup plan. 1~64 characters, the backup plan name of each data source type in a single warehouse required to be unique.
        :param pulumi.Input[str] options: This parameter specifies whether to use Windows VSS to define a backup path.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] paths: List of backup path. Up to 65536 characters. e.g.`["/home", "/var"]`. **Note** You should at least specify a backup path, empty array not allowed here.
        :param pulumi.Input[str] retention: Backup retention days, the minimum is 1.
        :param pulumi.Input[str] schedule: Backup strategy. Optional format: `I|{startTime}|{interval}`. It means to execute a backup task every `{interval}` starting from `{startTime}`. The backup task for the elapsed time will not be compensated. If the last backup task has not completed yet, the next backup task will not be triggered.
        :param pulumi.Input[str] vault_id: The ID of Backup vault.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NasBackupPlanState.__new__(_NasBackupPlanState)

        __props__.__dict__["backup_type"] = backup_type
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["cross_account_role_name"] = cross_account_role_name
        __props__.__dict__["cross_account_type"] = cross_account_type
        __props__.__dict__["cross_account_user_id"] = cross_account_user_id
        __props__.__dict__["disabled"] = disabled
        __props__.__dict__["file_system_id"] = file_system_id
        __props__.__dict__["nas_backup_plan_name"] = nas_backup_plan_name
        __props__.__dict__["options"] = options
        __props__.__dict__["paths"] = paths
        __props__.__dict__["retention"] = retention
        __props__.__dict__["schedule"] = schedule
        __props__.__dict__["vault_id"] = vault_id
        return NasBackupPlan(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="backupType")
    def backup_type(self) -> pulumi.Output[str]:
        """
        Backup type. Valid values: `COMPLETE`.
        """
        return pulumi.get(self, "backup_type")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        This field has been deprecated from provider version 1.153.0+. The creation time of NAS file system. **Note** The time format of the API adopts the ISO 8601, such as `2021-07-09T15:45:30CST` or `2021-07-09T07:45:30Z`.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="crossAccountRoleName")
    def cross_account_role_name(self) -> pulumi.Output[Optional[str]]:
        """
        The role name created in the original account RAM backup by the cross account managed by the current account.

        > **Note** `hbr.NasBackupPlan` depends on the `nas.FileSystem` and creates a mount point on the file system. If this dependency has not declared, the file system may not be deleted correctly.
        """
        return pulumi.get(self, "cross_account_role_name")

    @property
    @pulumi.getter(name="crossAccountType")
    def cross_account_type(self) -> pulumi.Output[str]:
        """
        The type of the cross account backup. Valid values: `SELF_ACCOUNT`, `CROSS_ACCOUNT`.
        """
        return pulumi.get(self, "cross_account_type")

    @property
    @pulumi.getter(name="crossAccountUserId")
    def cross_account_user_id(self) -> pulumi.Output[Optional[int]]:
        """
        The original account ID of the cross account backup managed by the current account.
        """
        return pulumi.get(self, "cross_account_user_id")

    @property
    @pulumi.getter
    def disabled(self) -> pulumi.Output[bool]:
        """
        Whether to disable the backup task. Valid values: `true`, `false`.
        """
        return pulumi.get(self, "disabled")

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> pulumi.Output[str]:
        """
        The File System ID of Nas.
        """
        return pulumi.get(self, "file_system_id")

    @property
    @pulumi.getter(name="nasBackupPlanName")
    def nas_backup_plan_name(self) -> pulumi.Output[str]:
        """
        The name of the backup plan. 1~64 characters, the backup plan name of each data source type in a single warehouse required to be unique.
        """
        return pulumi.get(self, "nas_backup_plan_name")

    @property
    @pulumi.getter
    def options(self) -> pulumi.Output[Optional[str]]:
        """
        This parameter specifies whether to use Windows VSS to define a backup path.
        """
        return pulumi.get(self, "options")

    @property
    @pulumi.getter
    def paths(self) -> pulumi.Output[Sequence[str]]:
        """
        List of backup path. Up to 65536 characters. e.g.`["/home", "/var"]`. **Note** You should at least specify a backup path, empty array not allowed here.
        """
        return pulumi.get(self, "paths")

    @property
    @pulumi.getter
    def retention(self) -> pulumi.Output[str]:
        """
        Backup retention days, the minimum is 1.
        """
        return pulumi.get(self, "retention")

    @property
    @pulumi.getter
    def schedule(self) -> pulumi.Output[str]:
        """
        Backup strategy. Optional format: `I|{startTime}|{interval}`. It means to execute a backup task every `{interval}` starting from `{startTime}`. The backup task for the elapsed time will not be compensated. If the last backup task has not completed yet, the next backup task will not be triggered.
        """
        return pulumi.get(self, "schedule")

    @property
    @pulumi.getter(name="vaultId")
    def vault_id(self) -> pulumi.Output[str]:
        """
        The ID of Backup vault.
        """
        return pulumi.get(self, "vault_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ApplicationInfoDimensionArgs',
    'QuotaAlarmQuotaDimensionArgs',
    'QuotaApplicationDimensionArgs',
    'TemplateQuotaDimensionArgs',
    'GetApplicationInfosDimensionArgs',
    'GetQuotaAlarmsQuotaDimensionArgs',
    'GetQuotaApplicationsDimensionArgs',
    'GetQuotasDimensionArgs',
]

@pulumi.input_type
class ApplicationInfoDimensionArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None):
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class QuotaAlarmQuotaDimensionArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] key: The Key of quota_dimensions.
        :param pulumi.Input[str] value: The Value of quota_dimensions.
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[str]]:
        """
        The Key of quota_dimensions.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        """
        The Value of quota_dimensions.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class QuotaApplicationDimensionArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] key: Key.
        :param pulumi.Input[str] value: Value.
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[str]]:
        """
        Key.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        """
        Value.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class TemplateQuotaDimensionArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] key: The Key of quota_dimensions.
        :param pulumi.Input[str] value: The Value of quota_dimensions.
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[str]]:
        """
        The Key of quota_dimensions.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        """
        The Value of quota_dimensions.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class GetApplicationInfosDimensionArgs:
    def __init__(__self__, *,
                 key: Optional[str] = None,
                 value: Optional[str] = None):
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[str]:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[str]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class GetQuotaAlarmsQuotaDimensionArgs:
    def __init__(__self__, *,
                 key: Optional[str] = None,
                 value: Optional[str] = None):
        """
        :param str key: The key of quota_dimensions.
        :param str value: The value of quota_dimensions.
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[str]:
        """
        The key of quota_dimensions.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[str]:
        """
        The value of quota_dimensions.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class GetQuotaApplicationsDimensionArgs:
    def __init__(__self__, *,
                 key: Optional[str] = None,
                 value: Optional[str] = None):
        """
        :param str key: The key of dimensions.
        :param str value: The value of dimensions.
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[str]:
        """
        The key of dimensions.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[str]:
        """
        The value of dimensions.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[str]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class GetQuotasDimensionArgs:
    def __init__(__self__, *,
                 key: Optional[str] = None,
                 value: Optional[str] = None):
        """
        :param str key: The key of dimensions.
        :param str value: The value of dimensions.
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[str]:
        """
        The key of dimensions.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[str]:
        """
        The value of dimensions.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[str]):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['SuspendProcessArgs', 'SuspendProcess']

@pulumi.input_type
class SuspendProcessArgs:
    def __init__(__self__, *,
                 process: pulumi.Input[str],
                 scaling_group_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a SuspendProcess resource.
        :param pulumi.Input[str] process: Activity type N that you want to suspend. Valid values are: `SCALE_OUT`,`SCALE_IN`,`HealthCheck`,`AlarmNotification` and `ScheduledAction`.
        :param pulumi.Input[str] scaling_group_id: ID of the scaling group.
        """
        pulumi.set(__self__, "process", process)
        pulumi.set(__self__, "scaling_group_id", scaling_group_id)

    @property
    @pulumi.getter
    def process(self) -> pulumi.Input[str]:
        """
        Activity type N that you want to suspend. Valid values are: `SCALE_OUT`,`SCALE_IN`,`HealthCheck`,`AlarmNotification` and `ScheduledAction`.
        """
        return pulumi.get(self, "process")

    @process.setter
    def process(self, value: pulumi.Input[str]):
        pulumi.set(self, "process", value)

    @property
    @pulumi.getter(name="scalingGroupId")
    def scaling_group_id(self) -> pulumi.Input[str]:
        """
        ID of the scaling group.
        """
        return pulumi.get(self, "scaling_group_id")

    @scaling_group_id.setter
    def scaling_group_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "scaling_group_id", value)


@pulumi.input_type
class _SuspendProcessState:
    def __init__(__self__, *,
                 process: Optional[pulumi.Input[str]] = None,
                 scaling_group_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SuspendProcess resources.
        :param pulumi.Input[str] process: Activity type N that you want to suspend. Valid values are: `SCALE_OUT`,`SCALE_IN`,`HealthCheck`,`AlarmNotification` and `ScheduledAction`.
        :param pulumi.Input[str] scaling_group_id: ID of the scaling group.
        """
        if process is not None:
            pulumi.set(__self__, "process", process)
        if scaling_group_id is not None:
            pulumi.set(__self__, "scaling_group_id", scaling_group_id)

    @property
    @pulumi.getter
    def process(self) -> Optional[pulumi.Input[str]]:
        """
        Activity type N that you want to suspend. Valid values are: `SCALE_OUT`,`SCALE_IN`,`HealthCheck`,`AlarmNotification` and `ScheduledAction`.
        """
        return pulumi.get(self, "process")

    @process.setter
    def process(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "process", value)

    @property
    @pulumi.getter(name="scalingGroupId")
    def scaling_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the scaling group.
        """
        return pulumi.get(self, "scaling_group_id")

    @scaling_group_id.setter
    def scaling_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scaling_group_id", value)


class SuspendProcess(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 process: Optional[pulumi.Input[str]] = None,
                 scaling_group_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Suspend/Resume processes to a specified scaling group.

        For information about scaling group suspend process, see [SuspendProcesses](https://www.alibabacloud.com/help/en/auto-scaling/latest/suspendprocesses).

        > NOTE: Available in v1.166.0+

        ## Import

        ### Timeouts The `timeouts` block allows you to specify timeouts for certain actions* `create` - (Defaults to 1 mins) Used when create the process. * `delete` - (Defaults to 1 mins) Used when delete the process.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] process: Activity type N that you want to suspend. Valid values are: `SCALE_OUT`,`SCALE_IN`,`HealthCheck`,`AlarmNotification` and `ScheduledAction`.
        :param pulumi.Input[str] scaling_group_id: ID of the scaling group.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SuspendProcessArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Suspend/Resume processes to a specified scaling group.

        For information about scaling group suspend process, see [SuspendProcesses](https://www.alibabacloud.com/help/en/auto-scaling/latest/suspendprocesses).

        > NOTE: Available in v1.166.0+

        ## Import

        ### Timeouts The `timeouts` block allows you to specify timeouts for certain actions* `create` - (Defaults to 1 mins) Used when create the process. * `delete` - (Defaults to 1 mins) Used when delete the process.

        :param str resource_name: The name of the resource.
        :param SuspendProcessArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SuspendProcessArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 process: Optional[pulumi.Input[str]] = None,
                 scaling_group_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SuspendProcessArgs.__new__(SuspendProcessArgs)

            if process is None and not opts.urn:
                raise TypeError("Missing required property 'process'")
            __props__.__dict__["process"] = process
            if scaling_group_id is None and not opts.urn:
                raise TypeError("Missing required property 'scaling_group_id'")
            __props__.__dict__["scaling_group_id"] = scaling_group_id
        super(SuspendProcess, __self__).__init__(
            'alicloud:ess/suspendProcess:SuspendProcess',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            process: Optional[pulumi.Input[str]] = None,
            scaling_group_id: Optional[pulumi.Input[str]] = None) -> 'SuspendProcess':
        """
        Get an existing SuspendProcess resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] process: Activity type N that you want to suspend. Valid values are: `SCALE_OUT`,`SCALE_IN`,`HealthCheck`,`AlarmNotification` and `ScheduledAction`.
        :param pulumi.Input[str] scaling_group_id: ID of the scaling group.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SuspendProcessState.__new__(_SuspendProcessState)

        __props__.__dict__["process"] = process
        __props__.__dict__["scaling_group_id"] = scaling_group_id
        return SuspendProcess(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def process(self) -> pulumi.Output[str]:
        """
        Activity type N that you want to suspend. Valid values are: `SCALE_OUT`,`SCALE_IN`,`HealthCheck`,`AlarmNotification` and `ScheduledAction`.
        """
        return pulumi.get(self, "process")

    @property
    @pulumi.getter(name="scalingGroupId")
    def scaling_group_id(self) -> pulumi.Output[str]:
        """
        ID of the scaling group.
        """
        return pulumi.get(self, "scaling_group_id")

